@@ -11,8 +11,8 @@ class ErrorsPrismaCloudAPICodeSecurityMixin:
     def errors_file_list(self, criteria):
         return self.execute_code_security('POST', 'code/api/v1/errors/file', body_params=criteria, paginated=True)
 
-    def errors_list_last_authors(self):
-        return self.execute_code_security('GET', 'code/api/v1/errors/gitBlameAuthors')
+    def errors_list_last_authors(self, query_params=None):
+        return self.execute_code_security('GET', 'code/api/v1/errors/gitBlameAuthors', query_params=query_params)
 
     def fix_or_suppress_scan_results(self, criteria):
         return self.execute_code_security('POST', 'code/api/v1/errors/submitActions', body_params=criteria)
