@@ -1,7 +1,6 @@
 """ Requests and Output """
 
 import json
-import sys
 import time
 
 import requests
@@ -89,13 +88,5 @@ class PrismaCloudAPICodeSecurityMixin():
     # Exit handler (Error).
 
     @classmethod
-    def error_and_exit(cls, error_code, error_message=None, system_message=None):
-        print()
-        print()
-        print('Status Code: %s' % error_code)
-        if error_message is not None:
-            print(error_message)
-        if system_message is not None:
-            print(system_message)
-        print()
-        sys.exit(1)
+    def error_and_exit(cls, error_code, error_message='', system_message=''):
+        raise SystemExit('\n\nStatus Code: %s\n%s\n%s\n' % (error_code, error_message, system_message))
